/**
 * Copyright 2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.testng4osgi;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.util.tracker.BundleTracker;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.maven.osgi.launcher.test.api.ITestLauncher;
import org.ow2.util.testng4osgi.launcher.TestNGLauncher;
import org.ow2.util.testng4osgi.tracker.TestNGBundleTracker;

/**
 * Bundle activator used to track all TestNG tests that are being added to the platform. 
 * @author Florent Benoit
 */
public class TestNGActivator implements BundleActivator {

    /**
     * Logger.
     */
    private static final Log LOGGER = LogFactory.getLog(TestNGActivator.class);

    /**
     * Tracking bundles (to detect testng tests).
     */
    private BundleTracker bundleTracker = null;

    /**
     * Our registration when we're ready
     */
    private ServiceRegistration<ITestLauncher> registration = null;

    /**
     * Start the activator.
     */
    public void start(BundleContext bundleContext) throws Exception {

        // New launcher
        TestNGLauncher testNGLauncher = new TestNGLauncher();

        // start tracking bundles
        bundleTracker = new BundleTracker(bundleContext, Bundle.ACTIVE, new TestNGBundleTracker(testNGLauncher));
        bundleTracker.open();

        // Registering the service as we're ready
        LOGGER.debug("Registering service ''{0}''", ITestLauncher.class);
        registration = bundleContext.registerService(ITestLauncher.class, testNGLauncher, null);

    }

    /**
     * Stop the activator.
     */
    public void stop(BundleContext context) throws Exception {
        // unregister
        if (registration != null) {
            registration.unregister();
        }

        // stop tracking
        if (bundleTracker != null) {
            bundleTracker.close();
        }

    }

}
