/**
 * Copyright 2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.testng4osgi.factory;

import org.osgi.framework.BundleContext;
import org.ow2.util.testng4osgi.inject.TestNGInject;
import org.testng.IObjectFactory2;

/**
 * Factory used to add dependency injection. 
 * @author Florent Benoit
 */
public class TestNGObjectFactory implements IObjectFactory2 {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 1704618482226341327L;

    /**
     * Inject helper.
     */
    private TestNGInject testNGInject = null;
    
    /**
     * Default constructor.
     * @param bundleContext the given bundle context
     */
    public TestNGObjectFactory(BundleContext bundleContext) {
        this.testNGInject = new TestNGInject(bundleContext);
    }
    
    /**
     * Callback used to instantiate a new instance of the given class
     * @param clazz the given class
     */
    public Object newInstance(Class<?> clazz) {
        Object instance = null;
        try {
            instance = clazz.newInstance();
        } catch (Exception e) {
            throw new IllegalStateException("Error while making instance", e);
        }
        testNGInject.inject(instance);
        return instance;
        
    }
}
