/**
 * Copyright 2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.testng4osgi.launcher;

import java.util.Arrays;
import java.util.List;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.testng.TestNG;
import org.testng.internal.Utils;
import org.testng.xml.XmlClass;
import org.testng.xml.XmlSuite;
import org.testng.xml.XmlTest;

/**
 * Allows to enhance TestNG
 * @author Florent Benoit
 */
public class EnhancedTestNG extends TestNG {

    /**
     * Logger.
     */
    private static final Log LOGGER = LogFactory.getLog(EnhancedTestNG.class);

    /**
     * Bundle context.
     */
    private BundleContext bundleContext = null;
    
    /**
     * Default constructor.
     * @param bundleContext the given bundle context
     */
    public EnhancedTestNG(BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }
    
    public void setOSGiClasses(List<Class<?>> classes) {

        // Create a new XML suite
        XmlClass[] xmlClassesArray = Utils.classesToXmlClasses(classes.toArray(new Class[classes.size()]));
        Bundle bundle = bundleContext.getBundle();
        String suiteName = "Bundle_".concat(bundle.getSymbolicName()).concat("_").concat(Long.toString(bundle.getBundleId()));
        XmlSuite xmlSuite = new XmlSuite();
        xmlSuite.setName(suiteName);
        XmlTest xmlTest = null;
        xmlTest = new XmlTest(xmlSuite);
        xmlTest.setName("Test");
        xmlTest.setXmlClasses(Arrays.asList(xmlClassesArray));
        
        setCommandLineSuite(xmlSuite);
        
    }
    
    
    @Override
    public void run() {
        try {
            super.run();
        } catch (RuntimeException e) {
            LOGGER.error("Error while running TestNG", e);
            setHasFailure(true);
        } catch (Exception e) {
            LOGGER.error("Error while running TestNG", e);
            setHasFailure(true);
        }
    }
    
    
}
